# json-tracer
A python library that generates a json file that traces the execution of a python program.

Can be run from command line or imported as a library.


## publish
```bash
python -m build
python -m twine upload dist/*
```
